import { MES_ROUTE } from './router';
import { BasicPageParams, BasicFetchResult } from '/@/api/model/baseModel';

export type OperParams = {
  OPER_CODE?: string;
  OPER_NAME?: string;
};
export type OperPageParams = BasicPageParams & OperParams;
export interface OperListItem {
  ID: string;
  OPER_CODE: string;
  OPER_NAME: string;
  OPER_TYPE: string;
  FACTORY: string;
  OPER_ACTION: string;
  IS_FPY: string;
  IS_REFLOW: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
  REMARK: string;
}

export type CheckRuleParams = {
  RULE_CODE?: string;
  RULE_NAME?: string;
};
export type CheckRulePageParams = BasicPageParams & CheckRuleParams;
export interface CheckRuleListItem {
  ID: string;
  CREATE_TIME: Date;
  CREATE_USER: string;
  UPDATE_TIME: Date;
  UPDATE_USER: string;
  // GHOST_ROW: boolean;
  // AUTH_ORG: string;
  // AUTH_PROD: string;
  // AUTH_WH: string;
  RULE_CODE: string;
  RULE_NAME: string;
  RULE_DESC: string;
  RULE_TYPE: number;
  PRIORITY: number;
  CODE_LENGTH: number;
  CHECK_TYPE: number;
  CHECK_REGEX: string;
  REMARK: string;
}

export type CheckRuleDtlParams = {
  RULE_ID: string;
};
export interface iBAS_CODE_DTL {
  ID: string;
  CREATE_TIME: Date;
  CREATE_USER: string;
  UPDATE_TIME: Date;
  UPDATE_USER: string;
  GHOST_ROW: boolean;
  AUTH_ORG: string;
  AUTH_PROD: string;
  AUTH_WH: string;
  RULE_ID: string;
  RULE_SEQ: number;
  DESCRIPTION: string;
  DATA_TYPE: number;
  DATA_CASE: string;
  DATA_VALUE: string;
  SERIAL_MIN: number;
  SERIAL_MAX: number;
  SERIAL_RESET: number;
  CHECK_TABLE: string;
  CHECK_FIELD: string;
  CHECK_LENGTH: number;
  REPEAT_TIMES: number;
  START_DIGIT: string;
  DATA_REGEX: string;
  REMARK: string;
}

export type MeslineParams = {
  LINE_CODE?: string;
  LINE_NAME?: string;
};
export type MeslinePageParams = BasicPageParams & MeslineParams;
export interface MeslineListItem {
  ID: string;
  LINE_CODE: string;
  LINE_NAME: string;
  WORKSHOP_CODE: string;
  FACTORY_CODE: string;
  ORG_ID: string;
  SHIFTTYPE_CODE: string;
  LOCATION: string;
  IS_ACTIVE: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
  REMARK: string;
}

export type MesBomParams = {
  MAT_ID?: string;
  PART_NO?: string;
  PARENT_NO?: string;
};
export type MesBomPageParams = BasicPageParams & MesBomParams;
export interface MesBomListItem {
  ID: string;
  MAT_ID: string;
  PART_NO: string;
  SPART_NO: string;
  FACTORY_CODE: string;
  QTY: string;
  EFFDATE: string;
  PARENT_NO: string;
  PART_STATUS: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
  REMARK: string;
}

export type MesModelParams = {
  MAT_MODEL?: string;
  MODEL_NAME?: string;
};
export type MesModelPageParams = BasicPageParams & MesModelParams;
export interface MesModelListItem {
  ID: string;
  MAT_MODEL: string;
  MODEL_NAME: string;
  MODEL_DESC: string;
  FACTORY_CODE: string;
  MAT_LINE: string;
  IS_INV: string;
  MAT_FAMILY: string;
  CREATE_USER: string;
  UPDATE_USER: string;
  UPDATE_TIME: string;
  CREATE_TIME: string;
}

export type RoutelistParams = {
  ROT_CODE?: string;
  ROT_NAME?: string;
  IS_ACTIVE?: string;
};
export type RoutelistPageParams = BasicPageParams & RoutelistParams;

export interface BIZ_MES_WO {
  ID: string;
  CREATE_TIME: Date;
  CREATE_USER: string;
  UPDATE_TIME: Date;
  UPDATE_USER: string;
  GHOST_ROW: boolean;
  AUTH_ORG: string;
  AUTH_PROD: string;
  AUTH_WH: string;
  ORDER_NO: string;
  ORDER_TYPE: string;
  ORDER_DESC: string;
  PARENT_ORDER: string;
  STATUS: number;
  ITEM_CODE: string;
  ITEM_TYPE: string;
  ITEM_MODEL: string;
  PRIORITY: string;
  CUST_CODE: string;
  ROUTE_CODE: string;
  ROUTE_STATUS: number;
  FACTORY: string;
  PLAN_LINE: string;
  ACT_LINE: string;
  PLAN_START_TIME: Date;
  PLAN_END_TIME: Date;
  ACT_START_TIME: Date;
  ACT_END_TIME: Date;
  STD_WORKERS_QTY: number;
  ACT_WORKER_QTY: number;
  IMPORT_TIME: Date;
  RELEASE_TIME: Date;
  RELEASE_USER: string;
  CHANGE_TIME: Date;
  CHANGE_USER: string;
  PLAN_QTY: number;
  INPUT_QTY: number;
  OUTPUT_QTY: number;
  SCRAP_QTY: number;
  STOCK_IN_QTY: number;
  UPH: number;
  UPPH: number;
  LAST_HIST_ID: string;
  REMARK: string;
  FBILLNO_ID: string;
  PREP_MSG: string;
}
export type BIZ_MES_WOParams = {
  ORDER_NO?: string;
  ITEM_CODE?: string;
  STATUS?: number;
  ORDER_TYPE?: string;
};
export type MesWolistPageParams = BasicPageParams & BIZ_MES_WOParams;

export interface MES_WORKSHOP {
  ID: string;
  CREATE_TIME: Date;
  CREATE_USER: string;
  UPDATE_TIME: Date;
  UPDATE_USER: string;
  GHOST_ROW: boolean;
  AUTH_ORG: string;
  AUTH_PROD: string;
  AUTH_WH: string;
  WS_CODE: string;
  WS_NAME: string;
  SHORT_NAME: string;
  FTY_CODE: string;
  ORG_CODE: string;
  IS_ACTIVE: string;
  REMARK: string;
}

export type MES_WORKSHOPParams = {
  WS_CODE?: string;
  WS_NAME?: string;
};
export type MesWslistPageParams = BasicPageParams & MES_WORKSHOPParams;

export interface BIZ_MES_WO_BATCH {
  ID: string;
  BATCH_NO: string;
  CREATE_TIME: Date;
  CREATE_USER: string;
  UPDATE_TIME: Date;
  UPDATE_USER: string;
  GHOST_ROW: boolean;
  AUTH_ORG: string;
  AUTH_PROD: string;
  AUTH_WH: string;
  ORDER_NO: string;
  STATUS: number;
  ITEM_CODE: string;
  CUST_CODE: string;
  FACTORY: string;
  WS_CODE: string;
  ACT_LINE: string;
  ACT_START_TIME: Date;
  ACT_END_TIME: Date;
  STD_WORKER_QTY: number;
  ACT_WORKER_QTY: number;
  RELEASE_TIME: Date;
  RELEASE_USER: string;
  PLAN_QTY: number;
  INPUT_QTY: number;
  OUTPUT_QTY: number;
  SCRAP_QTY: number;
  STOCK_IN_QTY: number;
  UPH: number;
  UPPH: number;
  REMARK: string;
}

export interface BAS_DEFECT {
	ID: string;
	CREATE_TIME: Date;
	CREATE_USER: string;
	UPDATE_TIME: Date;
	UPDATE_USER: string;
	GHOST_ROW: boolean;
	AUTH_ORG: string;
	AUTH_PROD: string;
	AUTH_WH: string;
	DFT_CODE: string;
	DFT_NAME: string;
	DFTG_CODE: string;
	DFT_LEVEL: number;
	REMARK: string;
}

export interface SaveWoBatchInput {
	Wo: BIZ_MES_WO;
	WoBatch: BIZ_MES_WO_BATCH;
}

export type OperPageListGetResultModel = BasicFetchResult<OperListItem>;
export type CheckRulePageListGetResultModel = BasicFetchResult<CheckRuleListItem>;
export type MeslinePageListGetResultModel = BasicFetchResult<MeslineListItem>;
export type MesBomPageListGetResultModel = BasicFetchResult<MesBomListItem>;
export type MesModelPageListGetResultModel = BasicFetchResult<MesModelListItem>;
export type RoutePageListGetResultModel = BasicFetchResult<MES_ROUTE>;
export type BIZ_MES_WOPageListGetResultModel = BasicFetchResult<BIZ_MES_WO>;
export type MES_WORKSHOPPageListGetResultModel = BasicFetchResult<MES_WORKSHOP>;

export interface DelWoRotInput {
  rotId: string;
  rotCode: string;
  wo: string;
}

export interface DelProdRotInput {
  rotId: string;
  rotCode: string;
  prodCode: string;
}

export interface BizMesWoInput {
  WorkOrder: string;
  UserId: string;
  Status: number;
  RouteStatus: number;
}

export interface BAS_LABEL_VAR_WO {
	ID: string;
	CREATE_TIME: Date;
	CREATE_USER: string;
	UPDATE_TIME: Date;
	UPDATE_USER: string;
	GHOST_ROW: boolean;
	AUTH_ORG: string;
	AUTH_PROD: string;
	AUTH_WH: string;
	LABEL_ID: string;
	VAR_NAME: string;
	VAR_VALUE: string;
	REMARK: string;
	LABEL_VIEW_PATH: string;
	WORK_ORDER: string;
	CUST_CODE: string;
	PROD_CODE: string;
}

export interface BAS_LABEL_TEMP {
	ID: string;
	CREATE_TIME: Date;
	CREATE_USER: string;
	UPDATE_TIME: Date;
	UPDATE_USER: string;
	GHOST_ROW: boolean;
	AUTH_ORG: string;
	AUTH_PROD: string;
	AUTH_WH: string;
	LABEL_CODE: string;
	LABEL_NAME: string;
	TEMP_TYPE: number;
	TEMP_PATH: string;
	CUST_CODE: string;
	PROD_CODE: string;
	REMARK: string;
}

export interface BAS_LABEL_VAR {
	ID: string;
	CREATE_TIME: Date;
	CREATE_USER: string;
	UPDATE_TIME: Date;
	UPDATE_USER: string;
	GHOST_ROW: boolean;
	AUTH_ORG: string;
	AUTH_PROD: string;
	AUTH_WH: string;
	LABEL_ID: string;
	VAR_NAME: string;
	VAR_TYPE: number;
	VAR_VALUE: string;
	REMARK: string;
}

export interface BasLabelTempInput {
  Label: BAS_LABEL_TEMP;
  LabelVars: BAS_LABEL_VAR[];
  LabelVarWos: BAS_LABEL_VAR_WO[];
}
